==> haskell-bytestring-show-0.3.5.6-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-show
version: 0.3.5.6
id: bytestring-show-0.3.5.6-LgqTvdUqaBW5ZRB1pkUuS0
key: bytestring-show-0.3.5.6-LgqTvdUqaBW5ZRB1pkUuS0
license: BSD-3-Clause
maintainer: Dan Doel <dan.doel@gmail.com>
author: Dan Doel
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient conversion of values into readable byte strings.
description:
    Efficient conversion of values into readable byte strings.
category: Text
abi: f6b27298afb5463991ca2e3e0f4bad6d
exposed: True
exposed-modules:
    Text.Show.ByteString
hidden-modules: Text.Show.ByteString.Util Text.Show.ByteString.Char
                Text.Show.ByteString.Int Text.Show.ByteString.Float
                Text.Show.ByteString.Integer
import-dirs: /usr/lib/ghc-8.6.1/site-local/bytestring-show-0.3.5.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/bytestring-show-0.3.5.6
hs-libraries: HSbytestring-show-0.3.5.6-LgqTvdUqaBW5ZRB1pkUuS0
depends:
    array-0.5.2.0 base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    containers-0.6.0.1 integer-gmp-1.0.2.0
haddock-interfaces: /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock
haddock-html: /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-show-0.3.5.6-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-show
version: 0.3.5.6
id: bytestring-show-0.3.5.6-9LsbtUHXG0YJS89oK68DPL
key: bytestring-show-0.3.5.6-9LsbtUHXG0YJS89oK68DPL
license: BSD-3-Clause
maintainer: Dan Doel <dan.doel@gmail.com>
author: Dan Doel
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient conversion of values into readable byte strings.
description:
    Efficient conversion of values into readable byte strings.
category: Text
abi: f602e6d5f6508386916ce516820a8a64
exposed: True
exposed-modules:
    Text.Show.ByteString
hidden-modules: Text.Show.ByteString.Util Text.Show.ByteString.Char
                Text.Show.ByteString.Int Text.Show.ByteString.Float
                Text.Show.ByteString.Integer
import-dirs: /usr/lib/ghc-8.6.2/site-local/bytestring-show-0.3.5.6
library-dirs: /usr/lib/ghc-8.6.2/site-local/bytestring-show-0.3.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/bytestring-show-0.3.5.6
hs-libraries: HSbytestring-show-0.3.5.6-9LsbtUHXG0YJS89oK68DPL
depends:
    array-0.5.3.0 base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    containers-0.6.0.1 integer-gmp-1.0.2.0
haddock-interfaces: /usr/share/doc/haskell-bytestring-show/html/bytestring-show.haddock
haddock-html: /usr/share/doc/haskell-bytestring-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
